@@ -78,3 +78,54 @@ def test_final_output_node_display__serialize_with_invalid_types_should_raise_er
 
     # AND the serialized workflow should still be created
     assert "workflow_raw_data" in serialized_workflow
+
+
+def test_final_output_node_display__serialize_with_list_str_type():
+    """
+    Tests that FinalOutputNode with list[str] as second type parameter serializes correctly.
+    """
+
+    # GIVEN a node that outputs a list of strings
+    class ListNode(BaseNode):
+
+        class Outputs:
+            result: list[str]
+
+    # AND a FinalOutputNode with list[str] as the second type parameter
+    class ListOutput(FinalOutputNode[BaseState, list[str]]):
+        class Outputs(FinalOutputNode.Outputs):
+            value = ListNode.Outputs.result
+
+    # AND a workflow referencing the node
+    class MyWorkflow(BaseWorkflow):
+        graph = ListNode >> ListOutput
+
+        class Outputs(BaseWorkflow.Outputs):
+            final_result = ListOutput.Outputs.value
+
+    # WHEN we serialize the workflow
+    workflow_display = get_workflow_display(workflow_class=MyWorkflow)
+    serialized_workflow: dict = workflow_display.serialize()
+
+    # THEN serialization should succeed without raising validation errors
+    assert "workflow_raw_data" in serialized_workflow
+    assert "nodes" in serialized_workflow["workflow_raw_data"]
+
+    # AND the terminal node should be properly serialized
+    terminal_node = next(
+        node for node in serialized_workflow["workflow_raw_data"]["nodes"] if node["type"] == "TERMINAL"
+    )
+    assert terminal_node is not None
+    assert terminal_node["id"] == str(ListOutput.__id__)
+
+    # AND the output type should be correctly serialized as ARRAY
+    assert terminal_node["data"]["output_type"] == "ARRAY"
+
+    # AND the outputs should contain the correct type information
+    assert len(terminal_node["outputs"]) == 1
+    assert terminal_node["outputs"][0]["type"] == "ARRAY"
+
+    # AND the output should have an inline type reference with JSON Schema
+    schema = terminal_node["outputs"][0]["schema"]
+    assert schema["type"] == "array"
+    assert schema["items"]["type"] == "string"
