@@ -105,7 +105,13 @@ def test_serialize_node__retry(serialize_node):
                 }
             ],
             "outputs": [
-                {"id": "78eece53-8a20-40a1-8a86-ffebe256282b", "name": "output", "type": "STRING", "value": None}
+                {
+                    "id": "78eece53-8a20-40a1-8a86-ffebe256282b",
+                    "name": "output",
+                    "type": "STRING",
+                    "value": None,
+                    "schema": {"type": "string"},
+                }
             ],
         },
         serialized_node,
@@ -197,7 +203,13 @@ def test_serialize_node__try(serialize_node):
                 }
             ],
             "outputs": [
-                {"id": "d8d0c9a8-0804-4b43-a874-28a7e7d6aec8", "name": "output", "type": "STRING", "value": None}
+                {
+                    "id": "d8d0c9a8-0804-4b43-a874-28a7e7d6aec8",
+                    "name": "output",
+                    "type": "STRING",
+                    "value": None,
+                    "schema": {"type": "string"},
+                }
             ],
         },
         serialized_node,
