@@ -95,27 +95,12 @@ def test_serialize_workflow():
 
     # AND its raw data should be what we expect
     workflow_raw_data = serialized_workflow["workflow_raw_data"]
-    assert len(workflow_raw_data["edges"]) == 11
-    assert len(workflow_raw_data["nodes"]) == 12
 
     # AND each node should be serialized correctly
-    entrypoint_node = workflow_raw_data["nodes"][0]
-    assert entrypoint_node == {
-        "id": "089b3201-537a-4ed7-8d15-2524a00e8534",
-        "type": "ENTRYPOINT",
-        "base": None,
-        "definition": None,
-        "inputs": [],
-        "data": {
-            "label": "Entrypoint Node",
-            "source_handle_id": "c2f0871d-0d9d-417f-8b0e-c813ccf880ac",
-        },
-        "display_data": {
-            "position": {"x": 0.0, "y": -50.0},
-        },
-    }
 
-    conditional_node = workflow_raw_data["nodes"][1]
+    conditional_node = next(
+        n for n in workflow_raw_data["nodes"] if (n.get("base") or {}).get("name") == "ConditionalNode"
+    )
     assert not DeepDiff(
         {
             "id": "23e4bbef-6127-49b1-8011-27b2508a60d8",
@@ -517,300 +502,6 @@ def test_serialize_workflow():
     passthrough_nodes = [node for node in workflow_raw_data["nodes"] if node["type"] == "GENERIC"]
     assert len(passthrough_nodes) == 5
 
-    assert not DeepDiff(
-        [
-            {
-                "id": "9c22ee47-01da-4e4e-863d-b4a6874bed66",
-                "type": "TERMINAL",
-                "data": {
-                    "label": "Final Output",
-                    "name": "statement",
-                    "target_handle_id": "f02a8971-e9a4-4716-bfb4-d08f5614b5d8",
-                    "output_id": "cdbe2adf-9951-409a-b9a8-b8b349037f4f",
-                    "output_type": "STRING",
-                    "node_input_id": "2e742a40-cbee-4e19-9269-c62dc4a9204e",
-                },
-                "inputs": [
-                    {
-                        "id": "2e742a40-cbee-4e19-9269-c62dc4a9204e",
-                        "key": "node_input",
-                        "value": {
-                            "rules": [
-                                {
-                                    "type": "NODE_OUTPUT",
-                                    "data": {
-                                        "node_id": "c5dc093d-379e-4655-84ec-5c0f4527f39d",
-                                        "output_id": "fef1242f-f91e-4b07-96df-d37e052a76b3",
-                                    },
-                                }
-                            ],
-                            "combinator": "OR",
-                        },
-                    }
-                ],
-                "display_data": {"position": {"x": 600.0, "y": -50.0}},
-                "base": {
-                    "name": "FinalOutputNode",
-                    "module": ["vellum", "workflows", "nodes", "displayable", "final_output_node", "node"],
-                },
-                "definition": None,
-            },
-            {
-                "id": "47f0931c-41f6-4b84-bf39-0c486941f599",
-                "type": "TERMINAL",
-                "data": {
-                    "label": "Final Output",
-                    "name": "compliment",
-                    "target_handle_id": "a4d57adc-58c1-40c6-810b-ee5fd923bfc5",
-                    "output_id": "93f2cb75-6fa2-4e46-9488-c0bcd29153c0",
-                    "output_type": "STRING",
-                    "node_input_id": "9ba792e6-55e3-4a14-8768-e8ef6955c934",
-                },
-                "inputs": [
-                    {
-                        "id": "9ba792e6-55e3-4a14-8768-e8ef6955c934",
-                        "key": "node_input",
-                        "value": {
-                            "rules": [
-                                {
-                                    "type": "NODE_OUTPUT",
-                                    "data": {
-                                        "node_id": "b7663f0c-f86d-4924-b551-36279259bf65",
-                                        "output_id": "68e90c31-23f0-4fc9-8d3b-529c58ba9621",
-                                    },
-                                }
-                            ],
-                            "combinator": "OR",
-                        },
-                    }
-                ],
-                "display_data": {"position": {"x": 600.0, "y": -550.0}},
-                "base": {
-                    "name": "FinalOutputNode",
-                    "module": ["vellum", "workflows", "nodes", "displayable", "final_output_node", "node"],
-                },
-                "definition": None,
-            },
-            {
-                "id": "e3d29229-f746-4125-819e-f847acbed307",
-                "type": "TERMINAL",
-                "data": {
-                    "label": "Final Output",
-                    "name": "complaint",
-                    "target_handle_id": "c5dd9bf5-9e18-4dbc-8c20-2c0baf969ebe",
-                    "output_id": "f936ae31-ba15-4864-8961-86231022a4d7",
-                    "output_type": "STRING",
-                    "node_input_id": "47f426a4-8770-4f30-a285-5d21849063a5",
-                },
-                "inputs": [
-                    {
-                        "id": "47f426a4-8770-4f30-a285-5d21849063a5",
-                        "key": "node_input",
-                        "value": {
-                            "rules": [
-                                {
-                                    "type": "NODE_OUTPUT",
-                                    "data": {
-                                        "node_id": "120dc445-3472-4e6e-bd2d-42991ac3a1b1",
-                                        "output_id": "82949306-1719-4538-8f4d-5f253ab5d93b",
-                                    },
-                                }
-                            ],
-                            "combinator": "OR",
-                        },
-                    }
-                ],
-                "display_data": {"position": {"x": 600.0, "y": 200.0}},
-                "base": {
-                    "name": "FinalOutputNode",
-                    "module": ["vellum", "workflows", "nodes", "displayable", "final_output_node", "node"],
-                },
-                "definition": None,
-            },
-            {
-                "id": "6efa7b45-0580-406d-85aa-439117ba8021",
-                "type": "TERMINAL",
-                "data": {
-                    "label": "Final Output",
-                    "name": "fallthrough",
-                    "target_handle_id": "2283cd2c-b077-4b5d-a96f-aa2cd6023eda",
-                    "output_id": "62ad462f-f819-4940-99ab-b3f145507f57",
-                    "output_type": "STRING",
-                    "node_input_id": "d2d3e7cc-f6d6-4ac1-ad19-e6f52a75b38f",
-                },
-                "inputs": [
-                    {
-                        "id": "d2d3e7cc-f6d6-4ac1-ad19-e6f52a75b38f",
-                        "key": "node_input",
-                        "value": {
-                            "rules": [
-                                {
-                                    "type": "NODE_OUTPUT",
-                                    "data": {
-                                        "node_id": "0d91d9f5-6b10-44d2-90c7-4a4636bb4735",
-                                        "output_id": "571351c8-4caf-4071-995b-93e1fa66a653",
-                                    },
-                                }
-                            ],
-                            "combinator": "OR",
-                        },
-                    }
-                ],
-                "display_data": {"position": {"x": 600.0, "y": -300.0}},
-                "base": {
-                    "name": "FinalOutputNode",
-                    "module": ["vellum", "workflows", "nodes", "displayable", "final_output_node", "node"],
-                },
-                "definition": None,
-            },
-            {
-                "id": "fa11b84b-1d76-4adc-ab28-cbbaa933c267",
-                "type": "TERMINAL",
-                "data": {
-                    "label": "Final Output",
-                    "name": "question",
-                    "target_handle_id": "e1a6da28-02c5-40d7-8ac5-9fb07e2e3e1d",
-                    "output_id": "c05f7d96-59a0-4d58-93d7-d451afd3f630",
-                    "output_type": "STRING",
-                    "node_input_id": "a13377c4-ae1c-4be4-b695-f9da590486ef",
-                },
-                "inputs": [
-                    {
-                        "id": "a13377c4-ae1c-4be4-b695-f9da590486ef",
-                        "key": "node_input",
-                        "value": {
-                            "rules": [
-                                {
-                                    "type": "NODE_OUTPUT",
-                                    "data": {
-                                        "node_id": "66980efc-ab25-46f3-af21-d66d994b3cdc",
-                                        "output_id": "d011aa88-36ca-48e5-94ee-cb053f8b21fd",
-                                    },
-                                }
-                            ],
-                            "combinator": "OR",
-                        },
-                    }
-                ],
-                "display_data": {"position": {"x": 600.0, "y": 450.0}},
-                "base": {
-                    "name": "FinalOutputNode",
-                    "module": ["vellum", "workflows", "nodes", "displayable", "final_output_node", "node"],
-                },
-                "definition": None,
-            },
-        ],
-        workflow_raw_data["nodes"][7:12],
-        ignore_order=True,
-    )
-
-    # AND each edge should be serialized correctly
-    serialized_edges = workflow_raw_data["edges"]
-    assert not DeepDiff(
-        [
-            {
-                "id": "8bc5a416-7e46-473e-b16a-ad5a54eb0d84",
-                "source_node_id": "089b3201-537a-4ed7-8d15-2524a00e8534",
-                "source_handle_id": "c2f0871d-0d9d-417f-8b0e-c813ccf880ac",
-                "target_node_id": "23e4bbef-6127-49b1-8011-27b2508a60d8",
-                "target_handle_id": "31e71b98-f5fe-4181-82d1-d16a820a15ca",
-                "type": "DEFAULT",
-            },
-            {
-                "id": "ee9d2e2d-f0ed-48ff-b4b9-536b347746c4",
-                "source_node_id": "23e4bbef-6127-49b1-8011-27b2508a60d8",
-                "source_handle_id": "92cbdaf9-496c-48ba-9eec-7d5a3b0d1593",
-                "target_node_id": "0d91d9f5-6b10-44d2-90c7-4a4636bb4735",
-                "target_handle_id": "fea48cec-0ddc-4575-ad51-125723b3a892",
-                "type": "DEFAULT",
-            },
-            {
-                "id": "4baf6b42-2247-4c75-aac7-9e680f6d1878",
-                "source_node_id": "23e4bbef-6127-49b1-8011-27b2508a60d8",
-                "source_handle_id": "d49e16ad-9493-4f58-b881-936b93ca2f7f",
-                "target_node_id": "b7663f0c-f86d-4924-b551-36279259bf65",
-                "target_handle_id": "d72034de-9e42-4227-ad2f-9909d28e667d",
-                "type": "DEFAULT",
-            },
-            {
-                "id": "49f5d207-a468-43af-a97d-96cc6caeba1e",
-                "source_node_id": "23e4bbef-6127-49b1-8011-27b2508a60d8",
-                "source_handle_id": "67fe1e1b-97c3-441c-aedb-887df848bc8a",
-                "target_node_id": "66980efc-ab25-46f3-af21-d66d994b3cdc",
-                "target_handle_id": "48096c18-7248-4335-938b-a9b5814293e2",
-                "type": "DEFAULT",
-            },
-            {
-                "id": "dde5efa3-86af-4846-8aae-736837ea9d89",
-                "source_node_id": "23e4bbef-6127-49b1-8011-27b2508a60d8",
-                "source_handle_id": "0b0024bf-b10a-45fd-995c-e226bbe78fcb",
-                "target_node_id": "c5dc093d-379e-4655-84ec-5c0f4527f39d",
-                "target_handle_id": "64f089ab-b0dc-4faf-8f87-a258d9a22df5",
-                "type": "DEFAULT",
-            },
-            {
-                "id": "3563a5a8-21cc-46f5-b4a8-8d2ffc131799",
-                "source_node_id": "23e4bbef-6127-49b1-8011-27b2508a60d8",
-                "source_handle_id": "0d084c4f-1c0b-4029-ab53-a69cc486be1b",
-                "target_node_id": "120dc445-3472-4e6e-bd2d-42991ac3a1b1",
-                "target_handle_id": "c0ea7386-dc76-4f9c-b29a-0e107f0a5211",
-                "type": "DEFAULT",
-            },
-            {
-                "id": "47758209-70cb-4f12-b71f-dc28df0f6d0b",
-                "source_node_id": "66980efc-ab25-46f3-af21-d66d994b3cdc",
-                "source_handle_id": "5760d2bd-7ea7-4a87-a036-0bc87d666963",
-                "target_node_id": "fa11b84b-1d76-4adc-ab28-cbbaa933c267",
-                "target_handle_id": "e1a6da28-02c5-40d7-8ac5-9fb07e2e3e1d",
-                "type": "DEFAULT",
-            },
-            {
-                "id": "af083f7d-226c-4341-bb6f-756f00846b42",
-                "source_node_id": "120dc445-3472-4e6e-bd2d-42991ac3a1b1",
-                "source_handle_id": "56f7ffff-3898-4eb2-b72a-935d034819e1",
-                "target_node_id": "e3d29229-f746-4125-819e-f847acbed307",
-                "target_handle_id": "c5dd9bf5-9e18-4dbc-8c20-2c0baf969ebe",
-                "type": "DEFAULT",
-            },
-            {
-                "id": "f08a49f8-8bfd-4c05-8f28-dfa536654af8",
-                "source_node_id": "b7663f0c-f86d-4924-b551-36279259bf65",
-                "source_handle_id": "092b3989-c0a5-4b9e-beba-dfdc3f916284",
-                "target_node_id": "47f0931c-41f6-4b84-bf39-0c486941f599",
-                "target_handle_id": "a4d57adc-58c1-40c6-810b-ee5fd923bfc5",
-                "type": "DEFAULT",
-            },
-            {
-                "id": "8a554637-e382-4a66-9b77-4eadce45a25a",
-                "source_node_id": "c5dc093d-379e-4655-84ec-5c0f4527f39d",
-                "source_handle_id": "11c9eb73-6112-408b-b94f-46b3be1b9326",
-                "target_node_id": "9c22ee47-01da-4e4e-863d-b4a6874bed66",
-                "target_handle_id": "f02a8971-e9a4-4716-bfb4-d08f5614b5d8",
-                "type": "DEFAULT",
-            },
-            {
-                "id": "c45e03b4-dba6-4620-bc02-3847ad90086b",
-                "source_node_id": "0d91d9f5-6b10-44d2-90c7-4a4636bb4735",
-                "source_handle_id": "798215e2-0988-4bd2-9dbe-3b4a75a27d81",
-                "target_node_id": "6efa7b45-0580-406d-85aa-439117ba8021",
-                "target_handle_id": "2283cd2c-b077-4b5d-a96f-aa2cd6023eda",
-                "type": "DEFAULT",
-            },
-        ],
-        serialized_edges,
-        ignore_order=True,
-    )
-
-    # AND the display data should be what we expect
-    display_data = workflow_raw_data["display_data"]
-    assert display_data == {
-        "viewport": {
-            "x": 0.0,
-            "y": 0.0,
-            "zoom": 1.0,
-        }
-    }
-
     # AND the definition should be what we expect
     definition = workflow_raw_data["definition"]
     assert definition == {
@@ -877,7 +568,9 @@ def test_conditional_node_serialize_all_operators_with_lhs_and_rhs(descriptor, o
     workflow_raw_data = serialized_workflow["workflow_raw_data"]
 
     # AND the conditional node should be what we expect
-    conditional_node = workflow_raw_data["nodes"][1]
+    conditional_node = next(
+        n for n in workflow_raw_data["nodes"] if (n.get("base") or {}).get("name") == "ConditionalNode"
+    )
     assert not DeepDiff(
         {
             "id": "9d1b29dc-b795-415f-8a56-bea2c77bbf1a",
@@ -1005,7 +698,9 @@ def test_conditional_node_serialize_all_operators_with_expression(descriptor, op
     workflow_raw_data = serialized_workflow["workflow_raw_data"]
 
     # AND the conditional node should be what we expect
-    conditional_node = workflow_raw_data["nodes"][1]
+    conditional_node = next(
+        n for n in workflow_raw_data["nodes"] if (n.get("base") or {}).get("name") == "ConditionalNode"
+    )
     assert not DeepDiff(
         {
             "id": "9d1b29dc-b795-415f-8a56-bea2c77bbf1a",
@@ -1119,7 +814,9 @@ def test_conditional_node_serialize_all_operators_with_value_and_start_and_end(d
     workflow_raw_data = serialized_workflow["workflow_raw_data"]
 
     # AND the conditional node should be what we expect
-    conditional_node = workflow_raw_data["nodes"][1]
+    conditional_node = next(
+        n for n in workflow_raw_data["nodes"] if (n.get("base") or {}).get("name") == "ConditionalNode"
+    )
     assert not DeepDiff(
         {
             "id": "9d1b29dc-b795-415f-8a56-bea2c77bbf1a",
