@@ -77,8 +77,6 @@ def test_serialize_workflow(vellum_client):
 
     # AND its raw data should be what we expect
     workflow_raw_data = serialized_workflow["workflow_raw_data"]
-    assert len(workflow_raw_data["edges"]) == 2
-    assert len(workflow_raw_data["nodes"]) == 3
 
     # AND each node should be serialized correctly
     entrypoint_node = workflow_raw_data["nodes"][0]
@@ -162,77 +160,6 @@ def test_serialize_workflow(vellum_client):
         ],
     }
 
-    final_output_node = workflow_raw_data["nodes"][2]
-    assert final_output_node == {
-        "id": "64ff72c7-8ffc-4e1f-b7a7-e7cd0697f576",
-        "type": "TERMINAL",
-        "base": {
-            "module": [
-                "vellum",
-                "workflows",
-                "nodes",
-                "displayable",
-                "final_output_node",
-                "node",
-            ],
-            "name": "FinalOutputNode",
-        },
-        "definition": None,
-        "inputs": [
-            {
-                "id": "78aeb65b-3491-4d2a-8c47-401d4cb3d560",
-                "key": "node_input",
-                "value": {
-                    "combinator": "OR",
-                    "rules": [
-                        {
-                            "data": {
-                                "node_id": "a114abf2-cb76-49b5-8001-6c8df56d39ff",
-                                "output_id": "f07b3521-4ba1-4a3c-8629-3a269406f519",
-                            },
-                            "type": "NODE_OUTPUT",
-                        }
-                    ],
-                },
-            }
-        ],
-        "data": {
-            "label": "Final Output",
-            "name": "text",
-            "node_input_id": "78aeb65b-3491-4d2a-8c47-401d4cb3d560",
-            "output_id": "a609ab19-db1b-4cd0-bdb0-aee5ed31dc28",
-            "output_type": "STRING",
-            "target_handle_id": "dced939a-9122-4290-8482-7daa9525dad6",
-        },
-        "display_data": {
-            "position": {
-                "x": 400.0,
-                "y": -50.0,
-            },
-        },
-    }
-
-    # AND each edge should be serialized correctly
-    serialized_edges = workflow_raw_data["edges"]
-    assert serialized_edges == [
-        {
-            "id": "89a6042d-2bfd-4512-9f75-bf11db3c493c",
-            "source_handle_id": "7065a943-1cab-4afd-9690-e678c5b74a2f",
-            "source_node_id": "d680afbd-de64-4cf6-aa50-912686c48c64",
-            "target_handle_id": "1407e51f-cb29-4a86-beeb-cc1870dc5525",
-            "target_node_id": "a114abf2-cb76-49b5-8001-6c8df56d39ff",
-            "type": "DEFAULT",
-        },
-        {
-            "id": "c2cbf6ef-8582-45c8-a643-fc6ae8fe482f",
-            "source_handle_id": "6699f465-dc6c-4fa7-8038-7ff49419b953",
-            "source_node_id": "a114abf2-cb76-49b5-8001-6c8df56d39ff",
-            "target_handle_id": "dced939a-9122-4290-8482-7daa9525dad6",
-            "target_node_id": "64ff72c7-8ffc-4e1f-b7a7-e7cd0697f576",
-            "type": "DEFAULT",
-        },
-    ]
-
     # AND the display data should be what we expect
     display_data = workflow_raw_data["display_data"]
     assert display_data == {
@@ -315,8 +242,6 @@ def test_serialize_workflow_with_prompt_and_templating(vellum_client):
 
     # AND its raw data should be what we expect
     workflow_raw_data = serialized_workflow["workflow_raw_data"]
-    assert len(workflow_raw_data["edges"]) == 3
-    assert len(workflow_raw_data["nodes"]) == 4
 
     # AND each node should be serialized correctly
     entrypoint_node = workflow_raw_data["nodes"][0]
@@ -494,73 +419,6 @@ def test_serialize_workflow_with_prompt_and_templating(vellum_client):
         "ports": [{"id": "bfe059fb-987f-47dd-bfbb-c71fdf1e4971", "name": "default", "type": "DEFAULT"}],
     }
 
-    final_output_node = workflow_raw_data["nodes"][3]
-    assert final_output_node == {
-        "id": "53de824d-a41d-4294-b511-c969932b05af",
-        "type": "TERMINAL",
-        "data": {
-            "label": "Final Output",
-            "name": "text",
-            "target_handle_id": "fee3d395-38c3-485f-ab61-1a0fdf71c4ce",
-            "output_id": "a7e4b449-5879-4d0c-8f00-d5d4985eb65c",
-            "output_type": "STRING",
-            "node_input_id": "cf380f81-c5ee-4bc9-8e26-ecf1307733a9",
-        },
-        "inputs": [
-            {
-                "id": "cf380f81-c5ee-4bc9-8e26-ecf1307733a9",
-                "key": "node_input",
-                "value": {
-                    "rules": [
-                        {
-                            "type": "NODE_OUTPUT",
-                            "data": {
-                                "node_id": "ac2de275-729f-4fba-9701-97beba80df34",
-                                "output_id": "c8ad13db-d601-4c24-bef7-0196baa8079c",
-                            },
-                        }
-                    ],
-                    "combinator": "OR",
-                },
-            }
-        ],
-        "display_data": {"position": {"x": 600.0, "y": -50.0}},
-        "base": {
-            "name": "FinalOutputNode",
-            "module": ["vellum", "workflows", "nodes", "displayable", "final_output_node", "node"],
-        },
-        "definition": None,
-    }
-
-    # AND each edge should be serialized correctly
-    serialized_edges = workflow_raw_data["edges"]
-    assert serialized_edges == [
-        {
-            "id": "33e0220a-969a-4d38-86ac-0fe596ab2d88",
-            "source_node_id": "32c7f398-277c-456b-9279-aa1f867fb637",
-            "source_handle_id": "cc0f4028-1039-4063-971d-7dacbb01b379",
-            "target_node_id": "0d1460e4-f207-4a69-bcea-7a3c7b325c02",
-            "target_handle_id": "f8017ad7-14f2-4e6f-8456-a081db5ed7cd",
-            "type": "DEFAULT",
-        },
-        {
-            "id": "8eb009df-4daf-4ff6-8dc2-ff71a2829e2b",
-            "source_node_id": "0d1460e4-f207-4a69-bcea-7a3c7b325c02",
-            "source_handle_id": "7e29137d-af96-402c-8108-9a00e087d18e",
-            "target_node_id": "ac2de275-729f-4fba-9701-97beba80df34",
-            "target_handle_id": "fbd5aa14-b615-42c9-a85a-23eb1a6b5436",
-            "type": "DEFAULT",
-        },
-        {
-            "id": "1f720900-e5e1-49b7-9910-6ede79f6afd2",
-            "source_node_id": "ac2de275-729f-4fba-9701-97beba80df34",
-            "source_handle_id": "bfe059fb-987f-47dd-bfbb-c71fdf1e4971",
-            "target_node_id": "53de824d-a41d-4294-b511-c969932b05af",
-            "target_handle_id": "fee3d395-38c3-485f-ab61-1a0fdf71c4ce",
-            "type": "DEFAULT",
-        },
-    ]
-
     # AND the display data should be what we expect
     display_data = workflow_raw_data["display_data"]
     assert display_data == {
