@@ -10,6 +10,7 @@ from vellum.workflows.nodes.bases.base import BaseNode
 from vellum.workflows.nodes.displayable.bases.utils import primitive_to_vellum_value
 from vellum.workflows.nodes.utils import get_unadorned_node
 from vellum.workflows.references import OutputReference, WorkflowInputReference
+from vellum.workflows.references.environment_variable import EnvironmentVariableReference
 from vellum.workflows.references.execution_count import ExecutionCountReference
 from vellum.workflows.references.lazy import LazyReference
 from vellum.workflows.references.node import NodeReference
@@ -68,12 +69,22 @@ class ExecutionCounterPointer(UniversalBaseModel):
     data: ExecutionCounterData
 
 
+class EnvironmentVariableData(UniversalBaseModel):
+    environment_variable: str
+
+
+class EnvironmentVariablePointer(UniversalBaseModel):
+    type: Literal["ENVIRONMENT_VARIABLE"] = "ENVIRONMENT_VARIABLE"
+    data: EnvironmentVariableData
+
+
 NodeInputValuePointerRule = Union[
     NodeOutputPointer,
     InputVariablePointer,
     ConstantValuePointer,
     WorkspaceSecretPointer,
     ExecutionCounterPointer,
+    EnvironmentVariablePointer,
 ]
 
 
@@ -152,6 +163,15 @@ def create_node_input_value_pointer_rule(
         return ExecutionCounterPointer(
             data=ExecutionCounterData(node_id=str(node_class_display.node_id)),
         )
+    if isinstance(value, EnvironmentVariableReference):
+        if value.serialize_as_constant:
+            vellum_value = primitive_to_vellum_value(value.name)
+            return ConstantValuePointer(type="CONSTANT_VALUE", data=vellum_value)
+        return EnvironmentVariablePointer(
+            data=EnvironmentVariableData(
+                environment_variable=value.name,
+            ),
+        )
 
     if not isinstance(value, BaseDescriptor):
         vellum_value = primitive_to_vellum_value(value)
