@@ -4,7 +4,6 @@ import fnmatch
 from functools import cached_property
 import importlib
 import inspect
-import json
 import logging
 import os
 import traceback
@@ -13,13 +12,13 @@ from typing import Any, Dict, ForwardRef, Generic, List, Optional, Set, Tuple, T
 
 from vellum.client import Vellum as VellumClient
 from vellum.client.core.pydantic_utilities import UniversalBaseModel
-from vellum.utils.json_encoder import VellumJsonEncoder
 from vellum.workflows import BaseWorkflow
 from vellum.workflows.constants import undefined
 from vellum.workflows.descriptors.base import BaseDescriptor
 from vellum.workflows.edges import Edge
 from vellum.workflows.edges.trigger_edge import TriggerEdge
 from vellum.workflows.events.workflow import NodeEventDisplayContext, WorkflowEventDisplayContext
+from vellum.workflows.exceptions import WorkflowInitializationException
 from vellum.workflows.inputs.base import BaseInputs
 from vellum.workflows.inputs.dataset_row import DatasetRow
 from vellum.workflows.nodes.bases import BaseNode
@@ -27,7 +26,7 @@ from vellum.workflows.nodes.displayable.bases.utils import primitive_to_vellum_v
 from vellum.workflows.nodes.displayable.final_output_node.node import FinalOutputNode
 from vellum.workflows.nodes.utils import get_unadorned_node, get_unadorned_port, get_wrapped_node
 from vellum.workflows.ports import Port
-from vellum.workflows.references import OutputReference, WorkflowInputReference
+from vellum.workflows.references import OutputReference, StateValueReference, WorkflowInputReference
 from vellum.workflows.triggers.integration import IntegrationTrigger
 from vellum.workflows.triggers.manual import ManualTrigger
 from vellum.workflows.triggers.schedule import ScheduleTrigger
@@ -52,7 +51,6 @@ from vellum_ee.workflows.display.nodes.base_node_display import BaseNodeDisplay
 from vellum_ee.workflows.display.nodes.get_node_display_class import get_node_display_class
 from vellum_ee.workflows.display.nodes.types import NodeOutputDisplay, PortDisplay
 from vellum_ee.workflows.display.nodes.utils import raise_if_descriptor
-from vellum_ee.workflows.display.nodes.vellum.utils import create_node_input
 from vellum_ee.workflows.display.types import (
     EdgeDisplays,
     EntrypointDisplays,
@@ -65,7 +63,7 @@ from vellum_ee.workflows.display.types import (
     WorkflowOutputDisplays,
 )
 from vellum_ee.workflows.display.utils.auto_layout import auto_layout_nodes
-from vellum_ee.workflows.display.utils.exceptions import UserFacingException
+from vellum_ee.workflows.display.utils.exceptions import UserFacingException, WorkflowValidationError
 from vellum_ee.workflows.display.utils.expressions import serialize_value
 from vellum_ee.workflows.display.utils.metadata import (
     get_entrypoint_edge_id,
@@ -144,6 +142,13 @@ class BaseWorkflowDisplay(Generic[WorkflowType]):
         self._dry_run = dry_run
 
     def serialize(self) -> JsonObject:
+        try:
+            self._workflow.validate()
+        except WorkflowInitializationException as e:
+            self.display_context.add_error(
+                WorkflowValidationError(message=e.message, workflow_class_name=self._workflow.__name__)
+            )
+
         self._serialized_files = [
             "__init__.py",
             "display/*",
@@ -276,7 +281,6 @@ class BaseWorkflowDisplay(Generic[WorkflowType]):
 
             serialized_nodes[dict_key] = serialized_node
 
-        synthetic_output_edges: JsonArray = []
         output_variables: JsonArray = []
         output_values: JsonArray = []
         final_output_nodes = [
@@ -284,98 +288,37 @@ class BaseWorkflowDisplay(Generic[WorkflowType]):
         ]
         final_output_node_outputs = {node.Outputs.value for node in final_output_nodes}
         unreferenced_final_output_node_outputs = final_output_node_outputs.copy()
-        final_output_node_base: JsonObject = {
-            "name": FinalOutputNode.__name__,
-            "module": cast(JsonArray, FinalOutputNode.__module__.split(".")),
-        }
 
-        # Add a synthetic Terminal Node and track the Workflow's output variables for each Workflow output
+        # Track the Workflow's output variables for each Workflow output
         for workflow_output, workflow_output_display in self.display_context.workflow_output_displays.items():
-            final_output_node_id = uuid4_from_hash(f"{self.workflow_id}|node_id|{workflow_output.name}")
             inferred_type = infer_vellum_variable_type(workflow_output)
             # Remove the terminal node output from the unreferenced set
             if isinstance(workflow_output.instance, OutputReference):
                 unreferenced_final_output_node_outputs.discard(workflow_output.instance)
 
-            if workflow_output.instance not in final_output_node_outputs:
-                # Create a synthetic terminal node only if there is no terminal node for this output
-                try:
-                    node_input = create_node_input(
-                        final_output_node_id,
-                        "node_input",
-                        # This is currently the wrapper node's output, but we want the wrapped node
-                        workflow_output.instance,
-                        self.display_context,
-                    )
-                except ValueError as e:
-                    raise ValueError(f"Failed to serialize output '{workflow_output.name}': {str(e)}") from e
-
-                source_node_display: Optional[BaseNodeDisplay]
-                if not node_input.value.rules:
-                    source_node_display = None
-                else:
-                    first_rule = node_input.value.rules[0]
-                    if first_rule.type == "NODE_OUTPUT":
-                        source_node_id = UUID(first_rule.data.node_id)
-                        try:
-                            source_node_display = [
-                                node_display
-                                for node_display in self.display_context.node_displays.values()
-                                if node_display.node_id == source_node_id
-                            ][0]
-                        except IndexError:
-                            source_node_display = None
-                    else:
-                        source_node_display = None
-
-                synthetic_target_handle_id = str(
-                    uuid4_from_hash(f"{self.workflow_id}|target_handle_id|{workflow_output_display.name}")
-                )
-                synthetic_display_data = NodeDisplayData().dict()
-                synthetic_node_label = "Final Output"
-                serialized_nodes[final_output_node_id] = {
-                    "id": str(final_output_node_id),
-                    "type": "TERMINAL",
-                    "data": {
-                        "label": synthetic_node_label,
-                        "name": workflow_output_display.name,
-                        "target_handle_id": synthetic_target_handle_id,
-                        "output_id": str(workflow_output_display.id),
-                        "output_type": inferred_type,
-                        "node_input_id": str(node_input.id),
-                    },
-                    "inputs": [node_input.dict()],
-                    "display_data": synthetic_display_data,
-                    "base": final_output_node_base,
-                    "definition": None,
-                }
-
-                if source_node_display:
-                    source_handle_id = source_node_display.get_source_handle_id(
-                        port_displays=self.display_context.port_displays
-                    )
-
-                    synthetic_output_edges.append(
-                        {
-                            "id": str(uuid4_from_hash(f"{self.workflow_id}|edge_id|{workflow_output_display.name}")),
-                            "source_node_id": str(source_node_display.node_id),
-                            "source_handle_id": str(source_handle_id),
-                            "target_node_id": str(final_output_node_id),
-                            "target_handle_id": synthetic_target_handle_id,
-                            "type": "DEFAULT",
-                        }
-                    )
-
-            elif isinstance(workflow_output.instance, OutputReference):
+            # Update the name of the terminal node if this output references a FinalOutputNode
+            if workflow_output.instance in final_output_node_outputs:
                 terminal_node_id = workflow_output.instance.outputs_class.__parent_class__.__id__
                 serialized_terminal_node = serialized_nodes.get(terminal_node_id)
-                if serialized_terminal_node and isinstance(serialized_terminal_node["data"], dict):
+                if (
+                    serialized_terminal_node
+                    and "data" in serialized_terminal_node
+                    and isinstance(serialized_terminal_node["data"], dict)
+                ):
                     serialized_terminal_node["data"]["name"] = workflow_output_display.name
 
+            try:
+                output_value = serialize_value(self.workflow_id, self.display_context, workflow_output.instance)
+            except UserFacingException as e:
+                self.display_context.add_error(
+                    UserFacingException(f"Failed to serialize output '{workflow_output.name}': {e}")
+                )
+                continue
+
             output_values.append(
                 {
                     "output_variable_id": str(workflow_output_display.id),
-                    "value": serialize_value(self.workflow_id, self.display_context, workflow_output.instance),
+                    "value": output_value,
                 }
             )
 
@@ -530,8 +473,6 @@ class BaseWorkflowDisplay(Generic[WorkflowType]):
                 regular_edge_dict["display_data"] = display_data
             edges.append(regular_edge_dict)
 
-        edges.extend(synthetic_output_edges)
-
         nodes_list = list(serialized_nodes.values())
         nodes_dict_list = [cast(Dict[str, Any], node) for node in nodes_list if isinstance(node, dict)]
 
@@ -1010,12 +951,12 @@ class BaseWorkflowDisplay(Generic[WorkflowType]):
             name = overrides.name
             color = overrides.color
         else:
-            workflow_input_id = uuid4_from_hash(f"{self.workflow_id}|inputs|id|{workflow_input.name}")
+            workflow_input_id = workflow_input.id
 
         return WorkflowInputsDisplay(id=workflow_input_id, name=name, color=color)
 
     def _generate_state_value_display(
-        self, state_value: BaseDescriptor, overrides: Optional[StateValueDisplay] = None
+        self, state_value: StateValueReference, overrides: Optional[StateValueDisplay] = None
     ) -> StateValueDisplay:
         state_value_id: UUID
         name = None
@@ -1025,7 +966,7 @@ class BaseWorkflowDisplay(Generic[WorkflowType]):
             name = overrides.name
             color = overrides.color
         else:
-            state_value_id = uuid4_from_hash(f"{self.workflow_id}|state_values|id|{state_value.name}")
+            state_value_id = state_value.id
 
         return StateValueDisplay(id=state_value_id, name=name, color=color)
 
@@ -1281,17 +1222,23 @@ class BaseWorkflowDisplay(Generic[WorkflowType]):
                     dataset = []
                     dataset_row_index_to_id = load_dataset_row_index_to_id_mapping(module)
                     for i, inputs_obj in enumerate(dataset_attr):
-                        if isinstance(inputs_obj, DatasetRow):
-                            serialized_inputs = json.loads(json.dumps(inputs_obj.inputs, cls=VellumJsonEncoder))
-                            row_data = {"label": inputs_obj.label, "inputs": serialized_inputs}
-                            trigger_class = inputs_obj.workflow_trigger
-                            if trigger_class is not None:
-                                row_data["workflow_trigger_id"] = str(trigger_class.__id__)
-                        elif isinstance(inputs_obj, BaseInputs):
-                            serialized_inputs = json.loads(json.dumps(inputs_obj, cls=VellumJsonEncoder))
-                            row_data = {"label": f"Scenario {i + 1}", "inputs": serialized_inputs}
-                        else:
-                            continue
+                        normalized_row = (
+                            DatasetRow(label=f"Scenario {i + 1}", inputs=inputs_obj)
+                            if isinstance(inputs_obj, BaseInputs)
+                            else inputs_obj
+                        )
+                        row_data = normalized_row.model_dump(
+                            mode="json",
+                            by_alias=True,
+                            exclude_none=True,
+                            context={
+                                "serializer": lambda value: serialize_value(
+                                    workflow_display.workflow_id,
+                                    workflow_display.display_context,
+                                    value,
+                                )
+                            },
+                        )
 
                         if i in dataset_row_index_to_id:
                             row_data["id"] = dataset_row_index_to_id[i]
