@@ -18,6 +18,7 @@ from vellum_ee.workflows.display.nodes.base_node_display import BaseNodeDisplay
 from vellum_ee.workflows.display.nodes.vellum.retry_node import BaseRetryNodeDisplay
 from vellum_ee.workflows.display.nodes.vellum.try_node import BaseTryNodeDisplay
 from vellum_ee.workflows.display.types import WorkflowDisplayContext
+from vellum_ee.workflows.display.utils.exceptions import UserFacingException
 from vellum_ee.workflows.display.workflows.get_vellum_workflow_display_class import get_workflow_display
 
 
@@ -41,7 +42,7 @@ def test_serialize_workflow__node_referenced_in_workflow_outputs_not_in_graph():
     workflow_display = get_workflow_display(workflow_class=Workflow)
 
     # THEN it should raise an error
-    with pytest.raises(ValueError) as exc_info:
+    with pytest.raises(UserFacingException) as exc_info:
         workflow_display.serialize()
 
     # AND the error message should be user friendly
@@ -63,7 +64,7 @@ def test_serialize_workflow__workflow_outputs_reference_non_node_outputs():
     workflow_display = get_workflow_display(workflow_class=Workflow)
 
     # THEN it should raise an error
-    with pytest.raises(ValueError) as exc_info:
+    with pytest.raises(UserFacingException) as exc_info:
         workflow_display.serialize()
 
     # AND the error message should be user friendly
@@ -528,8 +529,14 @@ def test_serialize_workflow__array_reference():
     # THEN it should serialize as an ARRAY_REFERENCE
     assert isinstance(data["workflow_raw_data"], dict)
     assert isinstance(data["workflow_raw_data"]["nodes"], list)
-    assert len(data["workflow_raw_data"]["nodes"]) == 5
-    second_node = data["workflow_raw_data"]["nodes"][2]
+    second_node = next(
+        node
+        for node in data["workflow_raw_data"]["nodes"]
+        if isinstance(node, dict)
+        and "definition" in node
+        and isinstance(node["definition"], dict)
+        and node["definition"]["name"] == "SecondNode"
+    )
     assert isinstance(second_node, dict)
 
     assert "outputs" in second_node
@@ -828,17 +835,6 @@ def test_serialize_workflow__empty_rules_indexerror():
     assert len(output_variables) == 1
     assert output_variables[0]["key"] == "problematic_output"
 
-    # AND the workflow raw data should contain nodes including terminal node
-    workflow_raw_data = result["workflow_raw_data"]
-    assert "nodes" in workflow_raw_data
-    nodes = workflow_raw_data["nodes"]
-
-    assert len(nodes) >= 3
-
-    terminal_nodes = [node for node in nodes if node.get("type") == "TERMINAL"]
-    assert len(terminal_nodes) == 1
-    assert terminal_nodes[0]["data"]["name"] == "problematic_output"
-
 
 def test_serialize_workflow__input_variables():
     # GIVEN a workflow with inputs
@@ -937,7 +933,7 @@ def test_serialize_workflow__state_variables():
 
     empty_string = next(var for var in state_variables if isinstance(var, dict) and var["key"] == "empty_string")
     assert empty_string == {
-        "id": "0ed1f179-1734-487f-b3ed-9e6026390d90",
+        "id": "c69e2507-f610-4a6f-84cc-a5bc2aa48551",
         "key": "empty_string",
         "type": "STRING",
         "default": {"type": "STRING", "value": ""},
@@ -947,7 +943,7 @@ def test_serialize_workflow__state_variables():
 
     state_1 = next(var for var in state_variables if isinstance(var, dict) and var["key"] == "state_1")
     assert state_1 == {
-        "id": "83c5b71d-56eb-42a5-84df-97e3591370c2",
+        "id": "151113d2-9bbf-428d-a1c1-0a9cf4fdedf3",
         "key": "state_1",
         "type": "STRING",
         "default": {"type": "STRING", "value": "hello"},
@@ -957,7 +953,7 @@ def test_serialize_workflow__state_variables():
 
     state_2 = next(var for var in state_variables if isinstance(var, dict) and var["key"] == "state_2")
     assert state_2 == {
-        "id": "9b0cfeec-aa66-42b3-8f31-aa7eb8ac30ea",
+        "id": "9a8d7a55-8bd2-497d-820c-dee665144a48",
         "key": "state_2",
         "type": "STRING",
         "default": None,
@@ -967,7 +963,7 @@ def test_serialize_workflow__state_variables():
 
     state_3 = next(var for var in state_variables if isinstance(var, dict) and var["key"] == "state_3")
     assert state_3 == {
-        "id": "3e19c570-6b46-4eab-ad81-d8d97028496f",
+        "id": "ffde4327-12c4-4c55-82d6-3ab88f0b1037",
         "key": "state_3",
         "type": "NUMBER",
         "default": {"type": "NUMBER", "value": 1.0},
@@ -977,7 +973,7 @@ def test_serialize_workflow__state_variables():
 
     state_4 = next(var for var in state_variables if isinstance(var, dict) and var["key"] == "state_4")
     assert state_4 == {
-        "id": "50c735de-f269-4d0a-b511-c9a1104451bb",
+        "id": "2467c1e6-b6aa-42d7-b079-84c8a650fbca",
         "key": "state_4",
         "type": "NUMBER",
         "default": {"type": "NUMBER", "value": 2.0},
