@@ -1,6 +1,7 @@
 import pytest
 from unittest.mock import MagicMock
 
+from vellum.client.core.api_error import ApiError
 from vellum.client.types.composio_execute_tool_response import ComposioExecuteToolResponse
 from vellum.workflows.errors.types import WorkflowErrorCode
 from vellum.workflows.exceptions import NodeException
@@ -32,29 +33,30 @@ def base_node_setup(vellum_client):
 
 
 def test_successful_search_with_results(base_node_setup):
-    """Test successful SerpAPI search with typical organic results."""
-    # GIVEN a mock Composio SerpAPI response with organic results
+    """Test successful SerpAPI search with typical results."""
+
+    # GIVEN a mock Composio SerpAPI response with results
     mock_response_data = {
-        "organic_results": [
-            {
-                "title": "First Result",
-                "snippet": "This is the first search result snippet",
-                "link": "https://example1.com",
-                "position": 1,
-            },
-            {
-                "title": "Second Result",
-                "snippet": "This is the second search result snippet",
-                "link": "https://example2.com",
-                "position": 2,
-            },
-            {
-                "title": "Third Result",
-                "snippet": "This is the third search result snippet",
-                "link": "https://example3.com",
-                "position": 3,
-            },
-        ]
+        "results": {
+            "organic_results": [
+                {
+                    "title": "First Result",
+                    "snippet": "This is the first search result snippet",
+                    "link": "https://example1.com",
+                    "position": 1,
+                },
+                {
+                    "title": "Second Result",
+                    "link": "https://example2.com",
+                    "position": 2,
+                },
+                {
+                    "title": "Third Result",
+                    "link": "https://example3.com",
+                    "position": 3,
+                },
+            ]
+        }
     }
 
     mock_response = ComposioExecuteToolResponse(provider="COMPOSIO", data=mock_response_data)
@@ -63,19 +65,42 @@ def test_successful_search_with_results(base_node_setup):
     # WHEN we run the node
     outputs = base_node_setup.run()
 
-    # THEN the text output should be properly formatted
-    expected_text = (
-        "First Result: This is the first search result snippet\n\n"
-        "Second Result: This is the second search result snippet\n\n"
-        "Third Result: This is the third search result snippet"
-    )
+    # THEN the text output should be properly formatted with labels
+    expected_text = """\
+Title: First Result
+Snippet: This is the first search result snippet
+URL: https://example1.com
+
+Title: Second Result
+URL: https://example2.com
+
+Title: Third Result
+URL: https://example3.com\
+"""
     assert outputs.text == expected_text
 
     # AND URLs should be extracted correctly
     assert outputs.urls == ["https://example1.com", "https://example2.com", "https://example3.com"]
 
-    # AND raw results should be preserved
-    assert outputs.results == mock_response_data["organic_results"]
+    # AND raw results should be serialized WebSearchResult models
+    assert len(outputs.results) == 3
+    assert outputs.results == [
+        {
+            "title": "First Result",
+            "snippet": "This is the first search result snippet",
+            "url": "https://example1.com",
+        },
+        {
+            "title": "Second Result",
+            "snippet": None,
+            "url": "https://example2.com",
+        },
+        {
+            "title": "Third Result",
+            "snippet": None,
+            "url": "https://example3.com",
+        },
+    ]
 
     # AND the Vellum client should have been called with the correct parameters
     base_node_setup._context.vellum_client.integrations.execute_integration_tool.assert_called_once_with(
@@ -87,22 +112,24 @@ def test_successful_search_with_results(base_node_setup):
 
 
 def test_authentication_error_401(base_node_setup):
-    """Test authentication error raises NodeException with PROVIDER_ERROR."""
+    """Test authentication error raises NodeException with PROVIDER_CREDENTIALS_UNAVAILABLE."""
+
     base_node_setup._context.vellum_client.integrations.execute_integration_tool = MagicMock(
-        side_effect=Exception("Authentication failed")
+        side_effect=ApiError(status_code=403, body={"detail": "You must authenticate with the search provider."})
     )
 
     # WHEN we run the node
     with pytest.raises(NodeException) as exc_info:
         base_node_setup.run()
 
-    # THEN it should raise the appropriate error
-    assert exc_info.value.code == WorkflowErrorCode.PROVIDER_ERROR
-    assert "Failed to execute web search" in str(exc_info.value)
+    # THEN it should raise the appropriate error with correct code
+    assert exc_info.value.code == WorkflowErrorCode.PROVIDER_CREDENTIALS_UNAVAILABLE
+    assert exc_info.value.message == "You must authenticate with the search provider."
 
 
 def test_serpapi_error_in_response(base_node_setup):
     """Test SerpAPI error field in response raises NodeException."""
+
     # GIVEN SerpAPI returns an error in the response data
     mock_response = ComposioExecuteToolResponse(provider="COMPOSIO", data={"error": "Invalid search parameters"})
     base_node_setup._context.vellum_client.integrations.execute_integration_tool = MagicMock(return_value=mock_response)
@@ -113,7 +140,7 @@ def test_serpapi_error_in_response(base_node_setup):
 
     # THEN it should raise the appropriate error
     assert exc_info.value.code == WorkflowErrorCode.PROVIDER_ERROR
-    assert "Invalid search parameters" in str(exc_info.value)
+    assert exc_info.value.message == "SerpAPI error: Invalid search parameters"
 
 
 def test_empty_query_validation(vellum_client):
@@ -133,13 +160,13 @@ def test_empty_query_validation(vellum_client):
 
     # THEN it should raise a validation error
     assert exc_info.value.code == WorkflowErrorCode.INVALID_INPUTS
-    assert "Query is required" in str(exc_info.value)
+    assert exc_info.value.message == "Query is required and must be a non-empty string"
 
 
 def test_empty_organic_results(base_node_setup):
     """Test handling of empty search results."""
-    # GIVEN Composio SerpAPI returns no organic results
-    mock_response = ComposioExecuteToolResponse(provider="COMPOSIO", data={"organic_results": []})
+    # GIVEN Composio SerpAPI returns no organic results in new format
+    mock_response = ComposioExecuteToolResponse(provider="COMPOSIO", data={"results": {"organic_results": []}})
     base_node_setup._context.vellum_client.integrations.execute_integration_tool = MagicMock(return_value=mock_response)
 
     # WHEN we run the node
@@ -152,20 +179,27 @@ def test_empty_organic_results(base_node_setup):
 
 
 def test_missing_fields_in_results(base_node_setup):
-    """Test handling of missing title, snippet, or link fields."""
-    # GIVEN Composio SerpAPI returns results with missing fields
+    """Test handling of results with missing optional snippet field."""
+    # GIVEN Composio SerpAPI returns results with some missing snippet fields
     mock_response_data = {
-        "organic_results": [
-            {
-                "title": "Only Title",
-            },
-            {"snippet": "Only snippet, no title or link"},
-            {
-                "title": "Title with link",
-                "link": "https://example.com",
-            },
-            {"position": 4},
-        ]
+        "results": {
+            "organic_results": [
+                {
+                    "title": "Result with snippet",
+                    "link": "https://example1.com",
+                    "snippet": "This has a snippet",
+                },
+                {
+                    "title": "Result without snippet",
+                    "link": "https://example2.com",
+                },
+                {
+                    "title": "Another with snippet",
+                    "link": "https://example3.com",
+                    "snippet": "Another snippet here",
+                },
+            ]
+        }
     }
 
     mock_response = ComposioExecuteToolResponse(provider="COMPOSIO", data=mock_response_data)
@@ -174,9 +208,39 @@ def test_missing_fields_in_results(base_node_setup):
     # WHEN we run the node
     outputs = base_node_setup.run()
 
-    # THEN text should handle missing fields gracefully
-    expected_text = "Only Title\n\n" "Only snippet, no title or link\n\n" "Title with link"
+    # THEN text should include all results with snippet only when present
+    expected_text = """\
+Title: Result with snippet
+Snippet: This has a snippet
+URL: https://example1.com
+
+Title: Result without snippet
+URL: https://example2.com
+
+Title: Another with snippet
+Snippet: Another snippet here
+URL: https://example3.com\
+"""
     assert outputs.text == expected_text
 
-    # AND URLs should only include valid links
-    assert outputs.urls == ["https://example.com"]
+    # AND URLs should include all links
+    assert outputs.urls == ["https://example1.com", "https://example2.com", "https://example3.com"]
+
+    assert len(outputs.results) == 3
+    assert outputs.results == [
+        {
+            "title": "Result with snippet",
+            "snippet": "This has a snippet",
+            "url": "https://example1.com",
+        },
+        {
+            "title": "Result without snippet",
+            "snippet": None,
+            "url": "https://example2.com",
+        },
+        {
+            "title": "Another with snippet",
+            "snippet": "Another snippet here",
+            "url": "https://example3.com",
+        },
+    ]
