@@ -1,5 +1,5 @@
 import os
-from typing import TYPE_CHECKING, Any, Optional
+from typing import TYPE_CHECKING, Any, Dict, Optional
 
 from vellum.workflows.constants import undefined
 from vellum.workflows.descriptors.base import BaseDescriptor
@@ -17,7 +17,7 @@ class EnvironmentVariableReference(BaseDescriptor[str]):
         default: Optional[str] = None,
         serialize_as_constant: bool = False,
     ):
-        super().__init__(name=name, types=(str,))
+        super().__init__(name=name, types=(str,), is_sensitive=True)
         self._serialize_as_constant = serialize_as_constant
 
     def resolve(self, state: "BaseState") -> Any:
@@ -27,6 +27,12 @@ class EnvironmentVariableReference(BaseDescriptor[str]):
 
         return undefined
 
+    def __vellum_encode__(self) -> Dict[str, Any]:
+        return {
+            "type": "ENVIRONMENT_VARIABLE",
+            "environment_variable": self.name,
+        }
+
     @property
     def serialize_as_constant(self) -> bool:
         return self._serialize_as_constant
