@@ -4,6 +4,7 @@ from threading import Event as ThreadingEvent
 from typing import (  # type: ignore[attr-defined]
     Any,
     Dict,
+    Iterable,
     List,
     Union,
     _GenericAlias,
@@ -17,6 +18,23 @@ JsonArray = List["Json"]
 JsonObject = Dict[str, "Json"]
 Json = Union[None, bool, int, float, str, JsonArray, JsonObject]
 
+
+def is_json_type(types: Iterable) -> bool:
+    # Check explicitly for our internal JSON type.
+    # Matches the type found at vellum.workflows.types.core.Json
+    actual_types_with_explicit_ref = [
+        bool,
+        int,
+        float,
+        str,
+        List[Json],
+        Dict[str, Json],
+    ]
+    with_none = [type(None), *actual_types_with_explicit_ref]
+    types_list = list(types)
+    return types_list == actual_types_with_explicit_ref or types_list == with_none
+
+
 CancelSignal = Union[ThreadingEvent, MultiprocessingEvent]
 
 # Unions and Generics inherit from `_GenericAlias` instead of `type`
