@@ -29,6 +29,7 @@ from typing import (
 
 from pydantic import ValidationError
 
+from vellum.utils.uuid import is_valid_uuid
 from vellum.workflows.edges import Edge
 from vellum.workflows.emitters.base import BaseWorkflowEmitter
 from vellum.workflows.errors import WorkflowError, WorkflowErrorCode
@@ -271,8 +272,6 @@ class BaseWorkflow(Generic[InputsType, StateType], BaseExecutable, metaclass=_Ba
         for resolver in self.resolvers:
             resolver.register_workflow_instance(self)
 
-        self.validate()
-
     @property
     def context(self) -> WorkflowContext:
         return self._context
@@ -604,15 +603,16 @@ class BaseWorkflow(Generic[InputsType, StateType], BaseExecutable, metaclass=_Ba
 
         return WorkflowEventGenerator(_generate_filtered_events(), runner_stream.span_id)
 
-    def validate(self) -> None:
+    @classmethod
+    def validate(cls) -> None:
         """
         Validates the Workflow, by running through our list of linter rules.
         """
-        # TODO: Implement rule that all entrypoints are non empty
-        # https://app.shortcut.com/vellum/story/4327
-        pass
 
-    def _resolve_node_ref(self, node_ref: Union[Type[BaseNode], UUID, str]) -> Type[BaseNode]:
+        cls._validate_no_self_edges()
+
+    @classmethod
+    def resolve_node_ref(cls, node_ref: Union[Type[BaseNode], UUID, str]) -> Type[BaseNode]:
         """
         Resolve a node reference (class, UUID, or string) to a node class.
 
@@ -630,18 +630,24 @@ class BaseWorkflow(Generic[InputsType, StateType], BaseExecutable, metaclass=_Ba
             return node_ref
 
         candidate_nodes: List[Type[BaseNode]] = []
-        for node in self.get_all_nodes():
+        for node in cls.get_all_nodes():
             candidate_nodes.append(node)
             wrapped_node = get_unadorned_node(node)
             if wrapped_node != node:
                 candidate_nodes.append(wrapped_node)
 
         if isinstance(node_ref, UUID):
+            node_uuid = node_ref
+        elif is_valid_uuid(node_ref):
+            node_uuid = UUID(node_ref)
+        else:
+            node_uuid = None
+
+        if node_uuid:
             for node in candidate_nodes:
-                if node.__id__ == node_ref:
+                if node.__id__ == node_uuid:
                     return node
-            identifier = str(node_ref)
-            raise WorkflowInitializationException(message=f"Node '{identifier}' not found in workflow")
+            raise WorkflowInitializationException(message=f"Node '{node_uuid}' not found in workflow")
 
         if isinstance(node_ref, str):
             try:
@@ -676,7 +682,7 @@ class BaseWorkflow(Generic[InputsType, StateType], BaseExecutable, metaclass=_Ba
         Raises:
             ValueError: If the node reference cannot be resolved
         """
-        resolved_node = self._resolve_node_ref(node)
+        resolved_node = self.resolve_node_ref(node)
         runner = WorkflowRunner(self)
         span_id = uuid4()
         node_instance = resolved_node(state=self.get_default_state(), context=self._context, inputs=inputs)
@@ -905,6 +911,35 @@ class BaseWorkflow(Generic[InputsType, StateType], BaseExecutable, metaclass=_Ba
         for emitter in self.emitters:
             emitter.join()
 
+    @classmethod
+    def _validate_no_self_edges(cls) -> None:
+        """
+        Validate that the workflow graph doesn't contain unconditional self-edges (infinite loops).
+
+        A node is considered to have an unconditional self-edge if all of its ports target itself.
+
+        Args:
+            edges: List of edge dictionaries from the serialized workflow
+
+        Raises:
+            WorkflowInitializationException: If an unconditional self-edge is detected
+        """
+
+        for node in cls.get_all_nodes():
+            node_ports = [list(port.edges) for port in node.Ports]
+            if (
+                all(
+                    all(edge.to_node == node for edge in port_edges) and len(port_edges) > 0
+                    for port_edges in node_ports
+                )
+                and len(node_ports) > 0
+            ):
+                raise WorkflowInitializationException(
+                    message=f"Graph contains a self-edge ({node.__name__} >> {node.__name__}).",
+                    workflow_definition=cls,
+                    code=WorkflowErrorCode.INVALID_WORKFLOW,
+                )
+
 
 WorkflowExecutionInitiatedBody.model_rebuild()
 WorkflowExecutionFulfilledBody.model_rebuild()
