@@ -3,6 +3,7 @@ import logging
 from uuid import UUID, uuid4
 
 from vellum.workflows.edges.edge import Edge
+from vellum.workflows.events.node import NodeExecutionFulfilledEvent, NodeExecutionInitiatedEvent
 from vellum.workflows.inputs.base import BaseInputs
 from vellum.workflows.nodes.bases.base import BaseNode
 from vellum.workflows.nodes.core.inline_subworkflow_node.node import InlineSubworkflowNode
@@ -684,3 +685,101 @@ def test_base_workflow__deserialize_state_with_invalid_workflow_definition(raw_w
 
     # AND the workflow definition should be BaseWorkflow
     assert state.meta.workflow_definition == BaseWorkflow
+
+
+def test_base_workflow__join_calls_runner_join():
+    """
+    Test that BaseWorkflow.join() calls runner.join() when runner exists.
+    """
+
+    # GIVEN a test workflow
+    class TestWorkflow(BaseWorkflow[BaseInputs, BaseState]):
+        pass
+
+    workflow = TestWorkflow()
+
+    # WHEN we run the workflow to create a runner
+    workflow.run()
+
+    workflow.join()
+
+    # THEN the runner should have been joined (verified by no hanging threads)
+    assert workflow._current_runner is not None
+
+
+def test_base_workflow__run_node_emits_correct_events():
+    """Test that WorkflowRunner.run_node method emits the expected events."""
+
+    class TestInputs(BaseInputs):
+        pass
+
+    class TestState(BaseState):
+        pass
+
+    class TestNode(BaseNode[TestState]):
+        class Outputs(BaseNode.Outputs):
+            result: str
+
+        def run(self) -> "TestNode.Outputs":
+            return self.Outputs(result="test_output")
+
+    class TestWorkflow(BaseWorkflow[TestInputs, TestState]):
+        graph = TestNode
+
+        class Outputs(BaseWorkflow.Outputs):
+            result: str
+
+    workflow = TestWorkflow()
+
+    events = list(workflow.run_node(node=TestNode))
+
+    assert len(events) == 2
+    assert isinstance(events[0], NodeExecutionInitiatedEvent)
+    assert isinstance(events[1], NodeExecutionFulfilledEvent)
+    assert events[0].span_id == events[1].span_id
+    assert events[1].body.outputs.result == "test_output"
+
+
+def test_base_workflow__run_node_with_inputs():
+    """Test that run_node method accepts and applies inputs parameter with dot notation."""
+
+    class TestInputs(BaseInputs):
+        pass
+
+    class TestState(BaseState):
+        pass
+
+    class TestCodeNode(BaseNode[TestState]):
+        code_inputs: dict = {"input1": "default_value", "input2": "default_value2"}
+        test_attr: str = "default"
+        another_attr: str = "not_overridden"
+
+        class Outputs(BaseNode.Outputs):
+            result: str
+
+        def run(self) -> "TestCodeNode.Outputs":
+            return self.Outputs(
+                result=f"{self.test_attr}_{self.code_inputs['input1']}_{self.code_inputs['input2']}_{self.another_attr}"
+            )
+
+    class TestWorkflow(BaseWorkflow[TestInputs, TestState]):
+        graph = TestCodeNode
+
+        class Outputs(BaseWorkflow.Outputs):
+            result: str
+
+    workflow = TestWorkflow()
+
+    inputs_data = {"test_attr": "overridden", "code_inputs.input1": "overridden_value"}
+
+    # WHEN we run the node with inputs
+    events = list(workflow.run_node(node=TestCodeNode, inputs=inputs_data))
+
+    # THEN the node should execute with the overridden attributes
+    assert len(events) == 2
+    assert isinstance(events[0], NodeExecutionInitiatedEvent)
+    assert isinstance(events[1], NodeExecutionFulfilledEvent)
+
+    # AND the execution result should use the overridden and non-overridden attributes
+    fulfilled_event = events[1]
+    assert fulfilled_event.body.outputs.result == "overridden_overridden_value_default_value2_not_overridden"
